@@ -11,10 +11,10 @@ class Command():
     def __init__(self, *args):
         self.args = args or []
 
-    def call(self, parse_log=False):
+    def call(self, **kwargs):
         out("Command: {}".format(' '.join(self.args)), 'important')
         try:
-            process = subprocess.Popen(self.args)
+            process = subprocess.Popen(self.args, **kwargs)
             process.communicate()
         except KeyboardInterrupt:
             try:
@@ -23,3 +23,7 @@ class Command():
             except OSError:
                 pass
             out("Odoo stopped by keyboard interrupt!", 'warning')
+
+    @staticmethod
+    def run(cmd):
+        Command(cmd).call(shell=True)
